@@ -31,7 +31,7 @@ Usage::
     list_types_paginator: ListTypesPaginator = client.get_paginator("list_types")
     ```
 """
-from mypy_boto3_appsync.client import AppSyncClient, AppSyncClient as Client
+from mypy_boto3_appsync.client import AppSyncClient
 from mypy_boto3_appsync.paginator import (
     ListApiKeysPaginator,
     ListDataSourcesPaginator,
@@ -42,6 +42,8 @@ from mypy_boto3_appsync.paginator import (
     ListTypesPaginator,
 )
 
+Client = AppSyncClient
+
 
 __all__ = (
     "AppSyncClient",
